==> aroundme_0_3_3.tar: aroundme_0_3_3/www/aroundme_0_3_3/language/1/am_default/g_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2004 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common_g.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_friends'] = 							"friends in group";
$lang['hdr_invite_friends'] = 					"invite friends";
$lang['hdr_non_member_friends'] = 				"friends who are not members of this group";
$lang['hdr_members'] = 							"members";
$lang['hdr_statistics'] = 						"statistics";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"invite";


//BODY TEXT
$lang['txt_apply'] = 							"apply";
$lang['txt_membership'] = 						"membership";//breadcrumb
$lang['txt_join_date'] = 						"join date";
$lang['txt_group_join_date'] = 					"group join date";
$lang['txt_open_group_invite'] = 				"This is an open group which means your friends can just go to the group and join. Just send them a message asking them to visit the group.";
$lang['txt_invite_friends'] = 					"To invite friends check the box next to each person that you want to invite and then press the 'invite' button. <p class=\"txt_footer\">Once you've invited them the group administrator(s) and moderator(s) will either accept or reject their membership as per the instructions laid out under the group rules.";
$lang['txt_user_name'] = 						"name";
$lang['txt_user_acquaintances'] = 				"acquaintances";
$lang['txt_user_level'] = 						"level";
$lang['txt_user_hometown'] = 					"home town";
$lang['txt_user_join_date'] = 					"community join date";
$lang['txt_user_nic'] = 						"nic";

?>

==> aroundme-0_4_0.tar: aroundme_0_4_0/www/aroundme_0_4_0/language/1/am_default/g_membership.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'g_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/


//HEADER
$lang['hdr_friends'] = 							"friends in group";
$lang['hdr_invite_friends'] = 					"invite friends";
$lang['hdr_non_member_friends'] = 				"friends who are not members of this group";
$lang['hdr_members'] = 							"members";
$lang['hdr_statistics'] = 						"statistics";


//SUBMIT BUTTONS
$lang['sub_invite'] = 							"invite";


//ERR
$lang['err_no_friends'] = 						"Sorry, you either have no friends or they are all already members of this group.";


//BODY TEXT
$lang['txt_apply'] = 							"apply";
$lang['txt_membership'] = 						"membership";//breadcrumb
$lang['txt_join_date'] = 						"join date";
$lang['txt_group_join_date'] = 					"group join date";
$lang['txt_open_group_invite'] = 				"This is an open group which means your friends can just go to the group and join. Just send them a message asking them to visit the group.";
$lang['txt_invite_friends'] = 					"To invite friends check the box next to each person that you want to invite and then press the 'invite' button. <p class=\"txt_footer\">Once you've invited them the group administrator(s) and moderator(s) will either accept or reject their membership as per the instructions laid out under the group rules.";
$lang['txt_user_name'] = 						"name";
$lang['txt_user_acquaintances'] = 				"acquaintances";
$lang['txt_role'] = 							"role";
$lang['txt_user_hometown'] = 					"home town";
$lang['txt_user_join_date'] = 					"community join date";
$lang['txt_user_nic'] = 						"nic";
$lang['txt_all_roles'] = 						"all roles";
$lang['txt_member_status'] = 					"status";

?>
